# 兰译 lfy <img src="data/resources/icons/hicolor/scalable/apps/cool.ldr.lfy.svg" width = "36" height = "36" alt="兰译" align=center />

<center>

gtk 版本

<div style="display: flex;">
    <img src="https://raw.githubusercontent.com/ldrfy/docs/main/images/gtk/main.png" alt="首页" style="width: 32%;">
    <img src="https://raw.githubusercontent.com/ldrfy/docs/main/images/gtk/preference.png" alt="设置" style="width: 32%;">
    <img src="https://raw.githubusercontent.com/ldrfy/docs/main/images/gtk/preference1.png" alt="设置1" style="width: 32%;">
</div>

qt 版本

<div style="display: flex; justify-content: space-between;">
    <img src="https://raw.githubusercontent.com/ldrfy/docs/main/images/qt/main.png" alt="首页" style="width: 32%;">
    <img src="https://raw.githubusercontent.com/ldrfy/docs/main/images/qt/preference.png" alt="设置" style="width: 32%;">
    <img src="https://raw.githubusercontent.com/ldrfy/docs/main/images/qt/preference1.png" alt="设置1" style="width: 32%;">
</div>
</center>

> 如果有python以及pip，qt版本可以直接通过终端安装

```bash
pip install lfy
```

支持全平台，包括windows11，mac应该也可以，终端即可运行
```bash
lfy
```

或者

- [自动编译，这里下载](https://github.com/ldrfy/lfy/releases/tag/auto)，包含`rpm`、`deb`、`flatpak`、`archlinux`、`whl`
- `archlinux最新版`、`ubuntu24.04`、`openSUSE Tumbleweed`、`Fedora41`
- 使用flatpak可以支持全平台

    <a href='https://flathub.org/apps/details/cool.ldr.lfy'><img width='120' alt='Download on Flathub' src='https://flathub.org/assets/badges/flathub-badge-en.png'/></a>


[软件文档](https://github.com/ldrfy/docs)

- [贡献说明](https://github.com/ldrfy/docs/blob/main/CONTRIBUTE.md)

- [翻译说明](https://github.com/ldrfy/docs/blob/main/TRANSLATE.md)

- [更新说明](https://github.com/ldrfy/docs/blob/main/CHANGELOG.md)
